@@ -502,6 +502,10 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)
 
+    def ResendSignupConfirmationCode(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ResendSignupConfirmationCode, request)
+
     def RevokeRefreshToken(self, request):
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
@@ -540,6 +544,12 @@ class AuthService:
     def RefreshTokenResponse(self, **kwargs):
         return auth_pb2.RefreshTokenResponse(**kwargs)
 
+    def ResendSignupConfirmationCodeRequest(self, **kwargs):
+        return auth_pb2.ResendSignupConfirmationCodeRequest(**kwargs)
+
+    def ResendSignupConfirmationCodeResponse(self, **kwargs):
+        return auth_pb2.ResendSignupConfirmationCodeResponse(**kwargs)
+
     def RevokeRefreshTokenRequest(self, **kwargs):
         return auth_pb2.RevokeRefreshTokenRequest(**kwargs)
 
